==> igniteui-react-layouts-18.3.1.tgz: package/esm2015/lib/igr-list-panel.js <==
import * as React from 'react';
import { ensureEnum, brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ReactRenderer } from "igniteui-react-core";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { ListPanel } from './ListPanel';
import { IgrListPanelTemplateItemUpdatingEventArgs } from './igr-list-panel-template-item-updating-event-args';
import { ListPanelOrientation_$type } from './ListPanelOrientation';
import { IgrListPanelContentRefreshedEventArgs } from './igr-list-panel-content-refreshed-event-args';
import { IgrListPanelTemplateWidthRequestedEventArgs } from './igr-list-panel-template-width-requested-event-args';
import { IgrListPanelTemplateHeightRequestedEventArgs } from './igr-list-panel-template-height-requested-event-args';
import { LocalDataSource } from "igniteui-react-core";
export class IgrListPanel extends React.Component {
    createLocalDataSource(itemsSource) {
        let lds = new LocalDataSource();
        lds.dataSource = itemsSource;
        return lds;
    }
    onContentSizeChanged() {
    }
    set height(value) {
        this._height = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this.i.notifySizeChanged();
        }
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this.i.notifySizeChanged();
        }
    }
    get width() {
        return this._width;
    }
    _getMainRef(ref) {
        this._elRef = ref;
        this.verifyReferences();
    }
    render() {
        let div = React.createElement("div", {
            ref: this._getMainRef,
            className: "ig-list-panel igr-list-panel",
        });
        return div;
    }
    verifyReferences() {
        if (this._elRef) {
            this._reactRenderer = new ReactRenderer(this._elRef, document, true, {});
            if (document) {
                this._elRef.style.display = "block";
                this._elRef.style.width = "100%";
                this._elRef.style.height = "100%";
            }
            // render needs to fire again after the portalManager is created. 
            this.i.provideContainer(this._reactRenderer);
            this.i.notifySizeChanged();
            this._reactRenderer.addSizeWatcher(() => {
                this.i.notifySizeChanged();
            });
        }
    }
    constructor(props) {
        super(props);
        this._implementation = null;
        this._reactRenderer = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._contentRefreshed = null;
        this._contentRefreshed_wrapped = null;
        this._rowUpdating = null;
        this._rowUpdating_wrapped = null;
        this._itemWidthRequested = null;
        this._itemWidthRequested_wrapped = null;
        this._itemHeightRequested = null;
        this._itemHeightRequested_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._getMainRef = this._getMainRef.bind(this);
        //var multiColumnComboBox = this.i;
        //multiColumnComboBox.notifySizeChanged();
        if (props) {
            this.initializeProperties();
        }
        this._initialized = true;
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    initializeProperties() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    // supports angular themes or custom properties set in CSS
    updateStyle() {
        this._styling(this._elRef, this);
    }
    componentWillUnmount() {
        this.i.destroy();
        if (this._reactRenderer)
            this._reactRenderer.destroy();
    }
    componentDidMount() {
        this._elRef.style.width = this._width ? this._width : "";
        this._elRef.style.height = this._height ? this._height : "";
        this.i.notifySizeChanged();
        this.initializeContent();
    }
    initializeContent() {
        this._styling(this._elRef, this);
        this.updateStyle();
        this.i.notifySizeChanged();
    }
    createImplementation() {
        return new ListPanel();
    }
    get i() {
        return this._implementation;
    }
    /**
 * Gets or Sets the property name that contains the values.
*/
    get rowHeight() {
        return this.i.a7;
    }
    set rowHeight(v) {
        this.i.a7 = +v;
    }
    get actualRowHeight() {
        return this.i.av;
    }
    set actualRowHeight(v) {
        this.i.av = +v;
    }
    /**
     * Gets or Sets the property name that contains the values.
    */
    get cellTextStyle() {
        if (this.i.s == null) {
            return null;
        }
        return this.i.s.fontString;
    }
    set cellTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.s = fi;
    }
    get hasUnevenSizes() {
        return this.i.ah;
    }
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get backgroundColor() {
        return brushToString(this.i.cs);
    }
    set backgroundColor(v) {
        this.i.cs = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get orientation() {
        return this.i.k;
    }
    set orientation(v) {
        this.i.k = ensureEnum(ListPanelOrientation_$type, v);
    }
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get isCustomRowHeightEnabled() {
        return this.i.ai;
    }
    set isCustomRowHeightEnabled(v) {
        this.i.ai = ensureBool(v);
    }
    /**
     * Gets or sets the color to use for the text of the component.
    */
    get textColor() {
        return brushToString(this.i.cv);
    }
    set textColor(v) {
        this.i.cv = stringToBrush(v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("ListPanel");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    /**
 * Gets the last visible index in the grid.

*/
    getLastVisibleIndex() {
        let iv = this.i.a4();
        return (iv);
    }
    /**
     * Gets the first visible index in the grid.
    
    */
    getFirstVisibleIndex() {
        let iv = this.i.a3();
        return (iv);
    }
    /**
     * Invalidates the bound data for the rows currently visible.
    
    */
    invalidateVisibleItems() {
        this.i.by();
    }
    notifySetItem(index, oldItem, newItem) {
        this.i.b4(index, oldItem, newItem);
    }
    /**
     * Manually notifies the grid's data source that the data it has bound to has been cleared and needs to be re-examined.
     * This should not be called if the data that the grid is bound to is already observable.
    
    */
    notifyClearItems() {
        this.i.b1();
    }
    notifyInsertItem(index, newItem) {
        this.i.b2(index, newItem);
    }
    notifyRemoveItem(index, oldItem) {
        this.i.b3(index, oldItem);
    }
    /**
     * Returns the data index of an item within the bound data source.
    
    * @param item  * The item from which to get the index.
    */
    dataIndexOfItem(item) {
        let iv = this.i.a1(item);
        return (iv);
    }
    dataIndexOfPrimaryKey(key) {
        let iv = this.i.a2(key);
        return (iv);
    }
    get contentRefreshed() {
        return this._contentRefreshed;
    }
    set contentRefreshed(ev) {
        if (this._contentRefreshed_wrapped !== null) {
            this.i.contentRefreshed = delegateRemove(this.i.contentRefreshed, this._contentRefreshed_wrapped);
            this._contentRefreshed_wrapped = null;
            this._contentRefreshed = null;
        }
        this._contentRefreshed = ev;
        this._contentRefreshed_wrapped = (o, e) => {
            let outerArgs = new IgrListPanelContentRefreshedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeContentRefreshed) {
                this.beforeContentRefreshed(this, outerArgs);
            }
            if (this._contentRefreshed) {
                this._contentRefreshed(this, outerArgs);
            }
        };
        this.i.contentRefreshed = delegateCombine(this.i.contentRefreshed, this._contentRefreshed_wrapped);
        ;
    }
    get rowUpdating() {
        return this._rowUpdating;
    }
    set rowUpdating(ev) {
        if (this._rowUpdating_wrapped !== null) {
            this.i.rowUpdating = delegateRemove(this.i.rowUpdating, this._rowUpdating_wrapped);
            this._rowUpdating_wrapped = null;
            this._rowUpdating = null;
        }
        this._rowUpdating = ev;
        this._rowUpdating_wrapped = (o, e) => {
            let outerArgs = new IgrListPanelTemplateItemUpdatingEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeRowUpdating) {
                this.beforeRowUpdating(this, outerArgs);
            }
            if (this._rowUpdating) {
                this._rowUpdating(this, outerArgs);
            }
        };
        this.i.rowUpdating = delegateCombine(this.i.rowUpdating, this._rowUpdating_wrapped);
        ;
    }
    get itemWidthRequested() {
        return this._itemWidthRequested;
    }
    set itemWidthRequested(ev) {
        if (this._itemWidthRequested_wrapped !== null) {
            this.i.itemWidthRequested = delegateRemove(this.i.itemWidthRequested, this._itemWidthRequested_wrapped);
            this._itemWidthRequested_wrapped = null;
            this._itemWidthRequested = null;
        }
        this._itemWidthRequested = ev;
        this._itemWidthRequested_wrapped = (o, e) => {
            let outerArgs = new IgrListPanelTemplateWidthRequestedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeItemWidthRequested) {
                this.beforeItemWidthRequested(this, outerArgs);
            }
            if (this._itemWidthRequested) {
                this._itemWidthRequested(this, outerArgs);
            }
        };
        this.i.itemWidthRequested = delegateCombine(this.i.itemWidthRequested, this._itemWidthRequested_wrapped);
        ;
    }
    get itemHeightRequested() {
        return this._itemHeightRequested;
    }
    set itemHeightRequested(ev) {
        if (this._itemHeightRequested_wrapped !== null) {
            this.i.itemHeightRequested = delegateRemove(this.i.itemHeightRequested, this._itemHeightRequested_wrapped);
            this._itemHeightRequested_wrapped = null;
            this._itemHeightRequested = null;
        }
        this._itemHeightRequested = ev;
        this._itemHeightRequested_wrapped = (o, e) => {
            let outerArgs = new IgrListPanelTemplateHeightRequestedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeItemHeightRequested) {
                this.beforeItemHeightRequested(this, outerArgs);
            }
            if (this._itemHeightRequested) {
                this._itemHeightRequested(this, outerArgs);
            }
        };
        this.i.itemHeightRequested = delegateCombine(this.i.itemHeightRequested, this._itemHeightRequested_wrapped);
        ;
    }
}

==> igniteui-react-layouts-18.6.1.tgz: package/esm2015/lib/igr-list-panel.js <==
import * as React from 'react';
import { ensureEnum, brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ReactRenderer } from "igniteui-react-core";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { ListPanel } from './ListPanel';
import { IgrListPanelTemplateItemUpdatingEventArgs } from './igr-list-panel-template-item-updating-event-args';
import { ListPanelOrientation_$type } from './ListPanelOrientation';
import { IgrListPanelContentRefreshedEventArgs } from './igr-list-panel-content-refreshed-event-args';
import { IgrListPanelTemplateWidthRequestedEventArgs } from './igr-list-panel-template-width-requested-event-args';
import { IgrListPanelTemplateHeightRequestedEventArgs } from './igr-list-panel-template-height-requested-event-args';
import { LocalDataSource } from "igniteui-react-core";
export class IgrListPanel extends React.Component {
    createLocalDataSource(itemsSource) {
        let lds = new LocalDataSource();
        lds.dataSource = itemsSource;
        return lds;
    }
    onContentSizeChanged() {
    }
    set height(value) {
        this._height = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this.i.notifySizeChanged();
        }
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this.i.notifySizeChanged();
        }
    }
    get width() {
        return this._width;
    }
    _getMainRef(ref) {
        this._elRef = ref;
        this.verifyReferences();
    }
    render() {
        let div = React.createElement("div", {
            ref: this._getMainRef,
            className: "ig-list-panel igr-list-panel",
        });
        return div;
    }
    verifyReferences() {
        if (this._elRef) {
            this._reactRenderer = new ReactRenderer(this._elRef, document, true, {});
            if (document) {
                this._elRef.style.display = "block";
                this._elRef.style.width = "100%";
                this._elRef.style.height = "100%";
            }
            // render needs to fire again after the portalManager is created. 
            this.i.provideContainer(this._reactRenderer);
            this.i.notifySizeChanged();
            this._reactRenderer.addSizeWatcher(() => {
                this.i.notifySizeChanged();
            });
        }
    }
    constructor(props) {
        super(props);
        this._implementation = null;
        this._reactRenderer = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._contentRefreshed = null;
        this._contentRefreshed_wrapped = null;
        this._rowUpdating = null;
        this._rowUpdating_wrapped = null;
        this._itemWidthRequested = null;
        this._itemWidthRequested_wrapped = null;
        this._itemHeightRequested = null;
        this._itemHeightRequested_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._getMainRef = this._getMainRef.bind(this);
        //var multiColumnComboBox = this.i;
        //multiColumnComboBox.notifySizeChanged();
        if (props) {
            this.initializeProperties();
        }
        this._initialized = true;
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    initializeProperties() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    // supports angular themes or custom properties set in CSS
    updateStyle() {
        this._styling(this._elRef, this);
    }
    componentWillUnmount() {
        this.i.destroy();
        if (this._reactRenderer)
            this._reactRenderer.destroy();
    }
    componentDidMount() {
        this._elRef.style.width = this._width ? this._width : "";
        this._elRef.style.height = this._height ? this._height : "";
        this.i.notifySizeChanged();
        this.initializeContent();
    }
    initializeContent() {
        this._styling(this._elRef, this);
        this.updateStyle();
        this.i.notifySizeChanged();
    }
    createImplementation() {
        return new ListPanel();
    }
    get i() {
        return this._implementation;
    }
    /**
 * Gets or Sets the property name that contains the values.
*/
    get rowHeight() {
        return this.i.a9;
    }
    set rowHeight(v) {
        this.i.a9 = +v;
    }
    get actualRowHeight() {
        return this.i.av;
    }
    set actualRowHeight(v) {
        this.i.av = +v;
    }
    /**
     * Gets or Sets the property name that contains the values.
    */
    get cellTextStyle() {
        if (this.i.s == null) {
            return null;
        }
        return this.i.s.fontString;
    }
    set cellTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.s = fi;
    }
    get hasUnevenSizes() {
        return this.i.ah;
    }
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get backgroundColor() {
        return brushToString(this.i.cv);
    }
    set backgroundColor(v) {
        this.i.cv = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get orientation() {
        return this.i.k;
    }
    set orientation(v) {
        this.i.k = ensureEnum(ListPanelOrientation_$type, v);
    }
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get isCustomRowHeightEnabled() {
        return this.i.ai;
    }
    set isCustomRowHeightEnabled(v) {
        this.i.ai = ensureBool(v);
    }
    /**
     * Gets or sets the color to use for the text of the component.
    */
    get textColor() {
        return brushToString(this.i.cy);
    }
    set textColor(v) {
        this.i.cy = stringToBrush(v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("ListPanel");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    /**
 * Gets the last visible index in the grid.

*/
    getLastVisibleIndex() {
        let iv = this.i.a6();
        return (iv);
    }
    /**
     * Gets the first visible index in the grid.
    
    */
    getFirstVisibleIndex() {
        let iv = this.i.a5();
        return (iv);
    }
    /**
     * Invalidates the bound data for the rows currently visible.
    
    */
    invalidateVisibleItems() {
        this.i.b1();
    }
    notifySetItem(index, oldItem, newItem) {
        this.i.b7(index, oldItem, newItem);
    }
    /**
     * Manually notifies the grid's data source that the data it has bound to has been cleared and needs to be re-examined.
     * This should not be called if the data that the grid is bound to is already observable.
    
    */
    notifyClearItems() {
        this.i.b4();
    }
    notifyInsertItem(index, newItem) {
        this.i.b5(index, newItem);
    }
    notifyRemoveItem(index, oldItem) {
        this.i.b6(index, oldItem);
    }
    /**
     * Returns the data index of an item within the bound data source.
    
    * @param item  * The item from which to get the index.
    */
    dataIndexOfItem(item) {
        let iv = this.i.a3(item);
        return (iv);
    }
    dataIndexOfPrimaryKey(key) {
        let iv = this.i.a4(key);
        return (iv);
    }
    get contentRefreshed() {
        return this._contentRefreshed;
    }
    set contentRefreshed(ev) {
        if (this._contentRefreshed_wrapped !== null) {
            this.i.contentRefreshed = delegateRemove(this.i.contentRefreshed, this._contentRefreshed_wrapped);
            this._contentRefreshed_wrapped = null;
            this._contentRefreshed = null;
        }
        this._contentRefreshed = ev;
        this._contentRefreshed_wrapped = (o, e) => {
            let outerArgs = new IgrListPanelContentRefreshedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeContentRefreshed) {
                this.beforeContentRefreshed(this, outerArgs);
            }
            if (this._contentRefreshed) {
                this._contentRefreshed(this, outerArgs);
            }
        };
        this.i.contentRefreshed = delegateCombine(this.i.contentRefreshed, this._contentRefreshed_wrapped);
        ;
    }
    get rowUpdating() {
        return this._rowUpdating;
    }
    set rowUpdating(ev) {
        if (this._rowUpdating_wrapped !== null) {
            this.i.rowUpdating = delegateRemove(this.i.rowUpdating, this._rowUpdating_wrapped);
            this._rowUpdating_wrapped = null;
            this._rowUpdating = null;
        }
        this._rowUpdating = ev;
        this._rowUpdating_wrapped = (o, e) => {
            let outerArgs = new IgrListPanelTemplateItemUpdatingEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeRowUpdating) {
                this.beforeRowUpdating(this, outerArgs);
            }
            if (this._rowUpdating) {
                this._rowUpdating(this, outerArgs);
            }
        };
        this.i.rowUpdating = delegateCombine(this.i.rowUpdating, this._rowUpdating_wrapped);
        ;
    }
    get itemWidthRequested() {
        return this._itemWidthRequested;
    }
    set itemWidthRequested(ev) {
        if (this._itemWidthRequested_wrapped !== null) {
            this.i.itemWidthRequested = delegateRemove(this.i.itemWidthRequested, this._itemWidthRequested_wrapped);
            this._itemWidthRequested_wrapped = null;
            this._itemWidthRequested = null;
        }
        this._itemWidthRequested = ev;
        this._itemWidthRequested_wrapped = (o, e) => {
            let outerArgs = new IgrListPanelTemplateWidthRequestedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeItemWidthRequested) {
                this.beforeItemWidthRequested(this, outerArgs);
            }
            if (this._itemWidthRequested) {
                this._itemWidthRequested(this, outerArgs);
            }
        };
        this.i.itemWidthRequested = delegateCombine(this.i.itemWidthRequested, this._itemWidthRequested_wrapped);
        ;
    }
    get itemHeightRequested() {
        return this._itemHeightRequested;
    }
    set itemHeightRequested(ev) {
        if (this._itemHeightRequested_wrapped !== null) {
            this.i.itemHeightRequested = delegateRemove(this.i.itemHeightRequested, this._itemHeightRequested_wrapped);
            this._itemHeightRequested_wrapped = null;
            this._itemHeightRequested = null;
        }
        this._itemHeightRequested = ev;
        this._itemHeightRequested_wrapped = (o, e) => {
            let outerArgs = new IgrListPanelTemplateHeightRequestedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeItemHeightRequested) {
                this.beforeItemHeightRequested(this, outerArgs);
            }
            if (this._itemHeightRequested) {
                this._itemHeightRequested(this, outerArgs);
            }
        };
        this.i.itemHeightRequested = delegateCombine(this.i.itemHeightRequested, this._itemHeightRequested_wrapped);
        ;
    }
}
